==> trackpy-0.4rc1.tar.gz: trackpy-0.4rc1/trackpy/api.py <==
from __future__ import (absolute_import, division, print_function,
                        unicode_literals)
import six
import warnings

from .find import percentile_threshold, grey_dilation
from .motion import msd, imsd, emsd, compute_drift, subtract_drift, \
           proximity, vanhove, relate_frames, velocity_corr, \
           direction_corr, is_typical, diagonal_size
from .static import proximity, pair_correlation_2d, pair_correlation_3d, \
           cluster
from .plots import annotate, annotate3d, plot_traj, ptraj, \
           plot_displacements, subpx_bias, mass_size, mass_ecc, \
           scatter, scatter3d, plot_traj3d, ptraj3d, plot_density_profile
from .linking import (link, link_df, link_iter, link_df_iter,
                      find_link, find_link_iter,
                      SubnetOversizeException, UnknownLinkingError)
from .filtering import filter_stubs, filter_clusters, filter
from .feature import locate, batch, local_maxima, \
           estimate_mass, estimate_size, minmass_v03_change, minmass_v04_change
from .preprocessing import bandpass, invert_image
from .framewise_data import FramewiseData, PandasHDFStore, PandasHDFStoreBig, \
           PandasHDFStoreSingleNode
from .refine import refine_com, refine_leastsq
from . import predict
from . import utils
from . import artificial
from .utils import handle_logging, ignore_logging, quiet
from .try_numba import try_numba_autojit, enable_numba, disable_numba


# pims import is deprecated. We include it here for backwards
# compatibility, but there will be warnings.
import pims as _pims


def _deprecate_pims(call):
    """Wrap a pims callable with a warning that it is deprecated."""
    def deprecated_pims_import(*args, **kw):
        """Class imported from pims package. Its presence in trackpy is deprecated."""
        warnings.warn(('trackpy.{0} is being called, but "{0}" is really part of the '
                      'pims package. It will not be in future versions of trackpy. '
                      'Consider importing pims and calling pims.{0} instead.'
                      ).format(call.__name__), UserWarning)
        return call(*args, **kw)
    return deprecated_pims_import


ImageSequence = _deprecate_pims(_pims.ImageSequence)
Video = _deprecate_pims(_pims.Video)
TiffStack = _deprecate_pims(_pims.TiffStack)

==> trackpy-0.4.2.tar.gz: trackpy-0.4.2/trackpy/api.py <==
from __future__ import (absolute_import, division, print_function,
                        unicode_literals)
import six
import warnings

from .find import percentile_threshold, grey_dilation
from .motion import msd, imsd, emsd, compute_drift, subtract_drift, \
           proximity, vanhove, relate_frames, velocity_corr, \
           direction_corr, is_typical, diagonal_size
from .static import proximity, pair_correlation_2d, pair_correlation_3d, \
           cluster
from .plots import annotate, annotate3d, plot_traj, ptraj, \
           plot_displacements, subpx_bias, mass_size, mass_ecc, \
           scatter, scatter3d, plot_traj3d, ptraj3d, plot_density_profile
from .linking import (link, link_df, link_iter, link_df_iter,
                      find_link, find_link_iter, link_partial,
                      SubnetOversizeException, UnknownLinkingError)
from .filtering import filter_stubs, filter_clusters, filter
from .feature import locate, batch, local_maxima, \
           estimate_mass, estimate_size, minmass_v03_change, minmass_v04_change
from .preprocessing import bandpass, invert_image
from .framewise_data import FramewiseData, PandasHDFStore, PandasHDFStoreBig, \
           PandasHDFStoreSingleNode
from .locate_functions import locate_brightfield_ring
from .refine import refine_com, refine_leastsq
from . import predict
from . import utils
from . import artificial
from .utils import handle_logging, ignore_logging, quiet
from .try_numba import try_numba_jit, enable_numba, disable_numba
